meme.alpha.core

meme public API: read and print meme syntax.

Three tracks: text-to-form: meme->forms, forms->meme (all platforms) form-to-text: forms->clj (all platforms), clj->forms (JVM only) text-to-text: meme->clj (all platforms), clj->meme (JVM only)

Pipeline: meme.alpha.pipeline/run — full ctx->ctx pipeline with intermediate state

meme public API: read and print meme syntax.

Three tracks:
  text-to-form:  meme->forms, forms->meme (all platforms)
  form-to-text:  forms->clj (all platforms), clj->forms (JVM only)
  text-to-text:  meme->clj (all platforms), clj->meme (JVM only)

Pipeline:
  meme.alpha.pipeline/run — full ctx->ctx pipeline with intermediate state
raw docstring

clj->formsclj

(clj->forms clj-src)

Read Clojure source string, return a vector of forms. JVM/Babashka only — Clojure's reader is needed for full form support.

Read Clojure source string, return a vector of forms.
JVM/Babashka only — Clojure's reader is needed for full form support.
sourceraw docstring

clj->memeclj

(clj->meme clj-src)

Convert Clojure source string to meme source string. JVM/Babashka only.

Convert Clojure source string to meme source string.
JVM/Babashka only.
sourceraw docstring

forms->cljclj/s

(forms->clj forms)

Print Clojure forms as Clojure source string.

Print Clojure forms as Clojure source string.
sourceraw docstring

forms->memeclj/s

(forms->meme forms)

Print Clojure forms as meme source string (single-line per form).

Print Clojure forms as meme source string (single-line per form).
sourceraw docstring

meme->cljclj/s

(meme->clj meme-src)
(meme->clj meme-src opts)

Convert meme source string to Clojure source string. opts map: same as meme->forms (e.g. :resolve-keyword).

Convert meme source string to Clojure source string.
opts map: same as meme->forms (e.g. :resolve-keyword).
sourceraw docstring

meme->formsclj/s

(meme->forms s)
(meme->forms s opts)

Read meme source string, return a vector of Clojure forms. opts map: :resolve-keyword — fn that resolves auto-resolve keyword strings ("::foo") to keywords at read time. Required on CLJS (errors without it, since cljs.reader cannot resolve :: correctly). Note: returns only parsed forms. Use run-pipeline when you need access to intermediate pipeline state (raw tokens, grouped tokens).

Read meme source string, return a vector of Clojure forms.
opts map:
  :resolve-keyword — fn that resolves auto-resolve keyword strings ("::foo")
                     to keywords at read time. Required on CLJS (errors
                     without it, since cljs.reader cannot resolve :: correctly).
Note: returns only parsed forms. Use run-pipeline when you need
access to intermediate pipeline state (raw tokens, grouped tokens).
sourceraw docstring

pprint-memeclj/s

(pprint-meme forms)
(pprint-meme forms opts)

Pretty-print Clojure forms as meme source string (multi-line, indented). opts: {:width 80}

Pretty-print Clojure forms as meme source string (multi-line, indented).
opts: {:width 80}
sourceraw docstring

run-pipelineclj/s

(run-pipeline source)
(run-pipeline source opts)

Run the full pipeline: source → scan → group → parse. Returns a context map with :source, :opts, :raw-tokens, :tokens, :forms. Useful for tooling that needs intermediate pipeline state.

Run the full pipeline: source → scan → group → parse.
Returns a context map with :source, :opts, :raw-tokens, :tokens, :forms.
Useful for tooling that needs intermediate pipeline state.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries