Pretty-printer: Clojure forms → idiomatic multi-line meme text. Width-aware — uses indented parenthesized form for multi-line calls.
Pretty-printer: Clojure forms → idiomatic multi-line meme text. Width-aware — uses indented parenthesized form for multi-line calls.
(pprint-form form)(pprint-form form opts)Pretty-print a single Clojure form as meme text. Preserves comments from :ws metadata. opts: {:width 80}
Pretty-print a single Clojure form as meme text.
Preserves comments from :ws metadata.
opts: {:width 80}(pprint-forms forms)(pprint-forms forms opts)Pretty-print a sequence of Clojure forms as meme text, separated by blank lines. Preserves comments from :ws metadata. opts: {:width 80}
Pretty-print a sequence of Clojure forms as meme text,
separated by blank lines. Preserves comments from :ws metadata.
opts: {:width 80}cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |