meme.alpha.rewrite.rules

Rewrite rule sets for S→M and M→S transformations. Each direction is a vector of rules for meme.alpha.rewrite/rewrite.

Rewrite rule sets for S→M and M→S transformations.
Each direction is a vector of rules for meme.alpha.rewrite/rewrite.
raw docstring

m->s-rulesclj/s

Rules that convert m-call nodes back to S-expression lists.

Rules that convert m-call nodes back to S-expression lists.
sourceraw docstring

s->m-rulesclj/s

Rules that tag S-expression calls as m-call nodes. List patterns only match lists (not vectors) — the engine distinguishes them.

Rules that tag S-expression calls as m-call nodes.
List patterns only match lists (not vectors) — the engine distinguishes them.
sourceraw docstring

transform-structuresclj/s

(transform-structures form)

Walk a tree and convert structural tags to Clojure data/AST nodes.

Walk a tree and convert structural tags to Clojure data/AST nodes.
sourceraw docstring

tree->s-rulesclj/s

Rules that flatten tagged tree nodes to Clojure forms.

Rules that flatten tagged tree nodes to Clojure forms.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries