Canonical formatter: width-aware meme output.
Composes printer (form → Doc) with render (layout @ target width).
Used by meme format CLI command.
Canonical formatter: width-aware meme output. Composes printer (form → Doc) with render (layout @ target width). Used by `meme format` CLI command.
(format-form form)(format-form form opts)Format a single Clojure form as canonical meme text. Width-aware — uses indented multi-line layout for forms that exceed width. Preserves comments from :ws metadata. opts: {:width 80}
Format a single Clojure form as canonical meme text.
Width-aware — uses indented multi-line layout for forms that exceed width.
Preserves comments from :ws metadata.
opts: {:width 80}(format-forms forms)(format-forms forms opts)Format a sequence of Clojure forms as canonical meme text, separated by blank lines. Preserves comments from :ws metadata. opts: {:width 80}
Format a sequence of Clojure forms as canonical meme text,
separated by blank lines. Preserves comments from :ws metadata.
opts: {:width 80}cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |