Rewrite rule sets for S→M and M→S transformations. Each direction is a vector of rules for meme.alpha.rewrite/rewrite.
Rewrite rule sets for S→M and M→S transformations. Each direction is a vector of rules for meme.alpha.rewrite/rewrite.
Rules that convert m-call nodes back to S-expression lists.
Rules that convert m-call nodes back to S-expression lists.
Rules that tag S-expression calls as m-call nodes. List patterns only match lists (not vectors) — the engine distinguishes them.
Rules that tag S-expression calls as m-call nodes. List patterns only match lists (not vectors) — the engine distinguishes them.
(transform-structures form)Walk a tree and convert structural tags to Clojure data/AST nodes.
Walk a tree and convert structural tags to Clojure data/AST nodes.
Rules that flatten tagged tree nodes to Clojure forms.
Rules that flatten tagged tree nodes to Clojure forms.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |